@@ -79,10 +79,6 @@ class TimeFrameAttributeSunPy(TimeAttribute):
                 raise ValueError('Invalid time input {0}={1!r}\n{2}'.format(self.name, value, err))
             converted = True
 
-        if not out.isscalar:
-            raise ValueError('Time input {0}={1!r} must be a single (scalar) value'
-                             .format(self.name, value))
-
         return out, converted
 
 
