@@ -166,13 +166,13 @@ of observer is correctly calculated.
 
 def test_default_observer_transform_hcc():
     center = frames.HeliographicStonyhurst(0 * u.deg, 0 * u.deg, obstime="2017-07-11 15:00")
-    hpc = center.transform_to(frames.Heliocentric)
+    hpc = center.transform_to(frames.Heliocentric(obstime="2017-07-11 15:00"))
 
     assert_quantity_allclose(hpc.y, -48471.1283979 * u.km)
 
 
 def test_default_observer_transform_hpc():
     center = frames.HeliographicStonyhurst(0 * u.deg, 0 * u.deg, obstime="2017-07-11 15:00")
-    hpc = center.transform_to(frames.Helioprojective)
+    hpc = center.transform_to(frames.Helioprojective(obstime="2017-07-11 15:00"))
 
     assert_quantity_allclose(hpc.Ty, -66.04425197 * u.arcsec)
