@@ -1,9 +1,9 @@
 """
-This module provides routines for the coalignment of images and mapcubes.
+This module provides routines for the coalignment of images and mapsequences.
 
 Currently this module provides image coalignment by template matching.
 Which is partially inspired by the SSWIDL routine
-`tr_get_disp.pro <http://hesperia.gsfc.nasa.gov/ssw/trace/idl/util/routines/tr_get_disp.pro>`_.
+`tr_get_disp.pro <http://www.heliodocs.com/php/xdoc_print.php?file=$SSW/trace/idl/util/tr_get_disp.pro>`_.
 
 In this implementation, the template matching is handled via the scikit-image
 routine :func:`skimage.feature.match_template`.
@@ -27,8 +27,9 @@ from astropy import units as u
 from skimage.feature import match_template
 
 # SunPy imports
-from sunpy.map.mapbase import GenericMap
 import sunpy.map
+from sunpy.util import deprecated
+from sunpy.map.mapbase import GenericMap
 
 __author__ = 'J. Ireland'
 
@@ -37,6 +38,7 @@ __all__ = ['calculate_shift', 'clip_edges', 'calculate_clipping',
            'get_correlation_shifts', 'parabolic_turning_point',
            'repair_image_nonfinite', 'apply_shifts',
            'mapcube_coalign_by_match_template',
+           'mapsequence_coalign_by_match_template',
            'calculate_match_template_shift']
 
 
@@ -354,14 +356,14 @@ def repair_image_nonfinite(image):
 @u.quantity_input(yshift=u.pix, xshift=u.pix)
 def apply_shifts(mc, yshift, xshift, clip=True, **kwargs):
     """
-    Apply a set of pixel shifts to a `~sunpy.map.MapCube`, and return a new
-    `~sunpy.map.MapCube`.
+    Apply a set of pixel shifts to a `~sunpy.map.MapSequence`, and return a new
+    `~sunpy.map.MapSequence`.
 
     Parameters
     ----------
-    mc : `sunpy.map.MapCube`
-        A `~sunpy.map.MapCube` of shape (ny, nx, nt), where nt is the number of
-        layers in the `~sunpy.map.MapCube`.  'ny' is the number of pixels in the
+    mc : `sunpy.map.MapSequence`
+        A `~sunpy.map.MapSequence` of shape (ny, nx, nt), where nt is the number of
+        layers in the `~sunpy.map.MapSequence`.  'ny' is the number of pixels in the
         y direction, 'nx' is the number of pixels in the 'x' direction.
 
     yshift : `~astropy.units.Quantity` instance
@@ -371,25 +373,25 @@ def apply_shifts(mc, yshift, xshift, clip=True, **kwargs):
         An array of pixel shifts in the x-direction for an image.
 
     clip : bool
-        If True, then clip off x, y edges in the datacube that are potentially
-        affected by edges effects.
+        If True, then clip off x, y edges of the maps in the sequence that are
+        potentially affected by edges effects.
 
     All other keywords are passed to `scipy.ndimage.interpolation.shift`.
 
     Returns
     -------
-    newmapcube : `sunpy.map.MapCube`
-        A `~sunpy.map.MapCube` of the same shape as the input.  All layers in
-        the `~sunpy.map.MapCube` have been shifted according the input shifts.
+    newmapsequence : `sunpy.map.MapSequence`
+        A `~sunpy.map.MapSequence` of the same shape as the input.  All layers in
+        the `~sunpy.map.MapSequence` have been shifted according the input shifts.
     """
-    # New mapcube will be constructed from this list
+    # New mapsequence will be constructed from this list
     new_mc = []
 
     # Calculate the clipping
     if clip:
         yclips, xclips = calculate_clipping(-yshift, -xshift)
 
-    # Shift the data and construct the mapcube
+    # Shift the data and construct the mapsequence
     for i, m in enumerate(mc):
         shifted_data = shift(deepcopy(m.data), [yshift[i].value, xshift[i].value], **kwargs)
         new_meta = deepcopy(m.meta)
@@ -407,35 +409,36 @@ def apply_shifts(mc, yshift, xshift, clip=True, **kwargs):
         # Append to the list
         new_mc.append(new_map)
 
-    return sunpy.map.Map(new_mc, cube=True)
+    return sunpy.map.Map(new_mc, sequence=True)
 
 
 def calculate_match_template_shift(mc, template=None, layer_index=0,
                                    func=_default_fmap_function):
     """
     Calculate the arcsecond shifts necessary to co-register the layers in a
-    `~sunpy.map.MapCube` according to a template taken from that
-    `~sunpy.map.MapCube`.  This method REQUIRES that scikit-image be installed.
+    `~sunpy.map.MapSequence` according to a template taken from that
+    `~sunpy.map.MapSequence`.
+
     When using this functionality, it is a good idea to check that the shifts
-    that were applied to were reasonable and expected.  One way of checking this
-    is to animate the original `~sunpy.map.MapCube`, animate the coaligned
-    `~sunpy.map.MapCube`, and compare the differences you see to the calculated
-    shifts.
+    that were applied to were reasonable and expected. One way of checking this
+    is to animate the original `~sunpy.map.MapSequence`, animate the coaligned
+    `~sunpy.map.MapSequence`, and compare the differences you see to the
+    calculated shifts.
 
     Parameters
     ----------
-    mc : `sunpy.map.MapCube`
-        A `~sunpy.map.MapCube` of shape (ny, nx, nt), where nt is the number of
-        layers in the `~sunpy.map.MapCube`.
+    mc : `sunpy.map.MapSequence`
+        A `~sunpy.map.MapSequence` of shape (ny, nx, nt), where nt is the number of
+        layers in the `~sunpy.map.MapSequence`.
 
     template : {None | `~sunpy.map.Map` | `~numpy.ndarray`}
         The template used in the matching.  If an `~numpy.ndarray` is passed,
         the `~numpy.ndarray` has to have two dimensions.
 
     layer_index : int
-        The template is assumed to refer to the map in the `~sunpy.map.MapCube`
+        The template is assumed to refer to the map in the `~sunpy.map.MapSequence`
         indexed by the value of "layer_index".  Displacements of all maps in the
-        `~sunpy.map.MapCube` are assumed to be relative to this layer.  The
+        `~sunpy.map.MapSequence` are assumed to be relative to this layer.  The
         displacements of the template relative to this layer are therefore
         (0, 0).
 
@@ -503,19 +506,19 @@ def calculate_match_template_shift(mc, template=None, layer_index=0,
 
     return {"x": xshift_arcseconds, "y": yshift_arcseconds}
 
-
-# Coalignment by matching a template
+@deprecated('0.9.1', alternative='mapsequence_coalign_by_match_template')
 def mapcube_coalign_by_match_template(mc, template=None, layer_index=0,
                                       func=_default_fmap_function, clip=True,
                                       shift=None, **kwargs):
     """
     Co-register the layers in a `~sunpy.map.MapCube` according to a template
-    taken from that `~sunpy.map.MapCube`.  This method REQUIRES that
-    scikit-image be installed. When using this functionality, it is a good idea
-    to check that the shifts that were applied to were reasonable and expected.
-    One way of checking this is to animate the original `~sunpy.map.MapCube`,
-    animate the coaligned `~sunpy.map.MapCube`, and compare the differences you
-    see to the calculated shifts.
+    taken from that `~sunpy.map.MapCube`.
+
+    When using this functionality, it is a good idea to check that the shifts
+    that were applied to were reasonable and expected. One way of checking this
+    is to animate the original `~sunpy.map.MapCube`, animate the coaligned
+    `~sunpy.map.MapCube`, and compare the differences you see to the calculated
+    shifts.
 
 
     Parameters
@@ -564,11 +567,86 @@ def mapcube_coalign_by_match_template(mc, template=None, layer_index=0,
     -------
     output : `sunpy.map.MapCube`
         A `~sunpy.map.MapCube` that has co-aligned by matching the template.
-
     Examples
     --------
     >>> from sunpy.image.coalignment import mapcube_coalign_by_match_template as mc_coalign
 
+    >>> coaligned_mc = mc_coalign(mc)   # doctest: +SKIP
+    >>> coaligned_mc = mc_coalign(mc, layer_index=-1)   # doctest: +SKIP
+    >>> coaligned_mc = mc_coalign(mc, clip=False)   # doctest: +SKIP
+    >>> coaligned_mc = mc_coalign(mc, template=sunpy_map)   # doctest: +SKIP
+    >>> coaligned_mc = mc_coalign(mc, template=two_dimensional_ndarray)   # doctest: +SKIP
+    >>> coaligned_mc = mc_coalign(mc, func=np.log)   # doctest: +SKIP
+    """
+    return mapsequence_coalign_by_match_template(mc, template, layer_index,
+                                                 func, clip, shift, **kwargs)
+
+
+# Coalignment by matching a template
+def mapsequence_coalign_by_match_template(mc, template=None, layer_index=0,
+                                          func=_default_fmap_function, clip=True,
+                                          shift=None, **kwargs):
+    """
+    Co-register the layers in a `~sunpy.map.MapSequence` according to a template
+    taken from that `~sunpy.map.MapSequence`.  This method REQUIRES that
+    scikit-image be installed. When using this functionality, it is a good idea
+    to check that the shifts that were applied to were reasonable and expected.
+    One way of checking this is to animate the original `~sunpy.map.MapSequence`,
+    animate the coaligned `~sunpy.map.MapSequence`, and compare the differences you
+    see to the calculated shifts.
+
+
+    Parameters
+    ----------
+    mc : `sunpy.map.MapSequence`
+        A `~sunpy.map.MapSequence` of shape (ny, nx, nt), where nt is the number of
+        layers in the `~sunpy.map.MapSequence`.
+    template : {None | sunpy.map.Map | `~numpy.ndarray`}
+        The template used in the matching.  If an `~numpy.ndarray` is passed,
+        the `~numpy.ndarray` has to have two dimensions.
+    layer_index : int
+        The template is assumed to refer to the map in the `~sunpy.map.MapSequence`
+        indexed by the value of "layer_index".  Displacements of all maps in the
+        `~sunpy.map.MapSequence` are assumed to be relative to this layer.  The
+        displacements of the template relative to this layer are therefore
+        (0, 0).
+    func : function
+        A function which is applied to the data values before the coalignment
+        method is applied.  This can be useful in coalignment, because it is
+        sometimes better to co-align on a function of the data rather than the
+        data itself.  The calculated shifts are applied to the original data.
+        Examples of useful functions to consider for EUV images are the
+        logarithm or the square root.  The function is of the form
+        func = F(data).  The default function ensures that the data are
+        floats.
+    clip : bool
+        If True, then clip off x, y edges of the maps in the sequence that are
+        potentially affected by edges effects.
+    shift : dict
+        A dictionary with two keys, 'x' and 'y'.  Key 'x' is an astropy
+        quantities array of corresponding to the amount of shift in the
+        x-direction (in arcseconds, assuming the helio-projective
+        Cartesian co-ordinate system) that is applied to the input
+        `~sunpy.map.MapSequence`.  Key 'y' is an `~astropy.units.Quantity` array
+        corresponding to the amount of shift in the y-direction (in arcseconds,
+        assuming the helio-projective Cartesian co-ordinate system) that is
+        applied to the input `~sunpy.map.MapSequence`. The number of elements in
+        each array must be the same as the number of maps in the
+        `~sunpy.map.MapSequence`.  If a shift is passed in to the function, that
+        shift is applied to the input `~sunpy.map.MapSequence` and the template
+        matching algorithm is not used.
+
+    The remaining keyword arguments are sent to `sunpy.image.coalignment.apply_shifts`.
+
+    Returns
+    -------
+    output : `sunpy.map.MapSequence`
+        A `~sunpy.map.MapSequence` that has co-aligned by matching the template.
+
+    Examples
+    --------
+    >>> from sunpy.image.coalignment import mapsequence_coalign_by_match_template as mc_coalign
+
     >>> coaligned_mc = mc_coalign(mc)   # doctest: +SKIP
     >>> coaligned_mc = mc_coalign(mc, layer_index=-1)   # doctest: +SKIP
     >>> coaligned_mc = mc_coalign(mc, clip=False)   # doctest: +SKIP
@@ -599,5 +677,5 @@ def mapcube_coalign_by_match_template(mc, template=None, layer_index=0,
         xshift_keep[i] = (xshift_arcseconds[i] / m.scale[0])
         yshift_keep[i] = (yshift_arcseconds[i] / m.scale[1])
 
-    # Apply the shifts and return the coaligned mapcube
+    # Apply the shifts and return the coaligned mapsequence
     return apply_shifts(mc, -yshift_keep, -xshift_keep, clip=clip, **kwargs)
