@@ -43,7 +43,7 @@ def aiaprep(aiamap):
     """
 
     if not isinstance(aiamap, (AIAMap, HMIMap)):
-        raise ValueError("Input must be an AIAMap")
+        raise ValueError("Input must be an AIAMap or HMIMap.")
 
     # Target scale is 0.6 arcsec/pixel, but this needs to be adjusted if the map
     # has already been rescaled.
@@ -64,5 +64,6 @@ def aiaprep(aiamap):
 
     newmap.meta['r_sun'] = newmap.meta['rsun_obs'] / newmap.meta['cdelt1']
     newmap.meta['lvl_num'] = 1.5
+    newmap.meta['bitpix'] = -64
 
     return newmap
