@@ -815,18 +815,11 @@ def calculate_radiative_loss_rate(goeslc, force_download=False,
 
     >>> goeslc_new = calculate_radiative_loss_rate(goeslc)  # doctest: +REMOTE_DATA
     >>> goeslc_new.data   # doctest:  +REMOTE_DATA
-                                        xrsa      xrsb  temperature            em  \\
-    2014-01-01 00:00:00.421999  9.187300e-08  0.000004     6.270239  6.440648e+48
-    2014-01-01 00:00:02.468999  9.187300e-08  0.000004     6.270239  6.440648e+48
-    2014-01-01 00:00:04.518999  9.187300e-08  0.000004     6.273917  6.422208e+48
-    2014-01-01 00:00:06.564999  9.298800e-08  0.000004     6.304001  6.350370e+48
-    <BLANKLINE>
-                                rad_loss_rate
-    2014-01-01 00:00:00.421999   5.449144e+19
-    2014-01-01 00:00:02.468999   5.449144e+19
-    2014-01-01 00:00:04.518999   5.434659e+19
-    2014-01-01 00:00:06.564999   5.382823e+19
-
+                                        xrsa      xrsb  temperature            em  rad_loss_rate
+    2014-01-01 00:00:00.421999  9.187300e-08  0.000004     6.270239  6.440648e+48   5.449144e+19
+    2014-01-01 00:00:02.468999  9.187300e-08  0.000004     6.270239  6.440648e+48   5.449144e+19
+    2014-01-01 00:00:04.518999  9.187300e-08  0.000004     6.273917  6.422208e+48   5.434659e+19
+    2014-01-01 00:00:06.564999  9.298800e-08  0.000004     6.304001  6.350370e+48   5.382823e+19
 
     """
     if not download_dir:
@@ -1074,17 +1067,11 @@ def calculate_xray_luminosity(goeslc):
 
     >>> goeslc_new = calculate_xray_luminosity(goeslc)  # doctest: +REMOTE_DATA
     >>> goeslc_new.data   # doctest:  +REMOTE_DATA
-                                        xrsa      xrsb  luminosity_xrsa  \\
-    2014-01-01 00:00:00.421999  9.187300e-08  0.000004     2.498454e+16
-    2014-01-01 00:00:02.468999  9.187300e-08  0.000004     2.498454e+16
-    2014-01-01 00:00:04.518999  9.187300e-08  0.000004     2.498454e+16
-    2014-01-01 00:00:06.564999  9.298800e-08  0.000004     2.528776e+16
-    <BLANKLINE>
-                                luminosity_xrsb
-    2014-01-01 00:00:00.421999     9.544507e+17
-    2014-01-01 00:00:02.468999     9.544507e+17
-    2014-01-01 00:00:04.518999     9.530365e+17
-    2014-01-01 00:00:06.564999     9.530365e+17
+                                        xrsa      xrsb  luminosity_xrsa  luminosity_xrsb
+    2014-01-01 00:00:00.421999  9.187300e-08  0.000004     2.498454e+16     9.544507e+17
+    2014-01-01 00:00:02.468999  9.187300e-08  0.000004     2.498454e+16     9.544507e+17
+    2014-01-01 00:00:04.518999  9.187300e-08  0.000004     2.498454e+16     9.530365e+17
+    2014-01-01 00:00:06.564999  9.298800e-08  0.000004     2.528776e+16     9.530365e+17
 
     """
     # Check that input argument is of correct type
