@@ -8,6 +8,7 @@ import sunpy.map
 
 __all__ = ['SJI_to_cube']
 
+
 def SJI_to_cube(filename, start=0, stop=None, hdu=0):
     """
     Read a SJI file and return a MapCube
@@ -37,8 +38,9 @@ def SJI_to_cube(filename, start=0, stop=None, hdu=0):
     """
 
     hdus = sunpy.io.read_file(filename)
-    #Get the time delta
-    time_range = sunpy.time.TimeRange(hdus[hdu][1]['STARTOBS'], hdus[hdu][1]['ENDOBS'])
+    # Get the time delta
+    time_range = sunpy.time.TimeRange(hdus[hdu][1]['STARTOBS'],
+                                      hdus[hdu][1]['ENDOBS'])
     splits = time_range.split(hdus[hdu][0].shape[0])
 
     if not stop:
@@ -47,10 +49,11 @@ def SJI_to_cube(filename, start=0, stop=None, hdu=0):
     headers = [hdus[hdu][1]]*(stop-start)
     datas = hdus[hdu][0][start:stop]
 
-    #Make the cube:
-    iris_cube = sunpy.map.Map(zip(datas,headers),cube=True)
-    #Set the date/time
-    for i,m in enumerate(iris_cube):
+    # Make the cube:
+    iris_cube = sunpy.map.Map(list(zip(datas, headers)), cube=True)
+    # Set the date/time
+
+    for i, m in enumerate(iris_cube):
         m.meta['DATE-OBS'] = splits[i].center.isoformat()
 
     return iris_cube
