@@ -2,8 +2,8 @@
 ANA File Reader
 
 .. warning::
-    The reading and writing of ana file is not supported under Windows or Python 3.
-    The C extensions will not be built in either case.
+    The reading and writing of ana file is not supported under Windows.
+    The C extensions are not built on Windows.
 
 Notes
 -----
@@ -18,6 +18,7 @@ Copyright (c) 2009--2011 Tim van Werkhoven.
 from __future__ import absolute_import, division, print_function
 
 import os
+import collections
 
 try:
     from sunpy.io import _pyana
@@ -28,6 +29,8 @@ from sunpy.io.header import FileHeader
 
 __all__ = ['read', 'get_header', 'write']
 
+HDPair = collections.namedtuple('HDPair', ['data', 'header'])
+
 
 def read(filename, debug=False, **kwargs):
     """
@@ -58,7 +61,8 @@ def read(filename, debug=False, **kwargs):
         raise ImportError("C extension for ANA is missing, please rebuild") # pragma: no cover
 
     data = _pyana.fzread(filename, debug)
-    return [(data['data'],FileHeader(data['header']))]
+    return [HDPair(data['data'], FileHeader(data['header']))]
+
 
 def get_header(filename, debug=False):
     """
