@@ -61,7 +61,7 @@ class TestFiletools(object):
         assert isinstance(pair[0][1], sunpy.io.header.FileHeader)
 
     def test_read_file_header_fits(self):
-        #Test FITS
+        # Test FITS
         hlist = sunpy.io.read_file_header(AIA_171_IMAGE)
         assert isinstance(hlist, list)
         assert len(hlist) == 1
@@ -69,15 +69,15 @@ class TestFiletools(object):
 
     @skip_glymur
     def test_read_file_header_jp2(self):
-        #Test jp2
+        # Test jp2
         hlist = sunpy.io.read_file_header(os.path.join(sunpy.data.test.rootdir,
-                               "2013_06_24__17_31_30_84__SDO_AIA_AIA_193.jp2"))
+                                            "2013_06_24__17_31_30_84__SDO_AIA_AIA_193.jp2"))
         assert isinstance(hlist, list)
         assert len(hlist) == 1
         assert isinstance(hlist[0], sunpy.io.header.FileHeader)
 
     def test_write_file_fits(self):
-        #Test write FITS
+        # Test write FITS
         aiapair = sunpy.io.read_file(AIA_171_IMAGE)[0]
         sunpy.io.write_file("aia_171_image.fits", aiapair[0], aiapair[1],
                             clobber=True)
@@ -87,6 +87,17 @@ class TestFiletools(object):
         assert outpair[1] == aiapair[1]
         os.remove("aia_171_image.fits")
 
+    def test_write_file_fits_bytes(self):
+        # Test write FITS
+        aiapair = sunpy.io.read_file(AIA_171_IMAGE)[0]
+        with open("aia_171_image_bytes.fits", 'wb') as fileo:
+            sunpy.io.write_file(fileo, aiapair[0], aiapair[1], filetype='fits')
+        assert os.path.exists("aia_171_image_bytes.fits")
+        outpair = sunpy.io.read_file(AIA_171_IMAGE)[0]
+        assert np.all(np.equal(outpair[0], aiapair[0]))
+        assert outpair[1] == aiapair[1]
+        os.remove("aia_171_image_bytes.fits")
+
     @skip_ana
     def test_read_file_ana(self):
         ana_data = sunpy.io.read_file(os.path.join(sunpy.data.test.rootdir,"test_ana.fz"))
