@@ -1,11 +1,13 @@
-import sunpy.io.fits
-from sunpy.io.fits import get_header, extract_waveunit
-
-import sunpy.data.test
 import os
+from collections import OrderedDict
 
+import astropy.io.fits as fits
+
+import sunpy.io.fits
+import sunpy.data.test
+from sunpy.util import MetaDict
+from sunpy.io.fits import get_header, extract_waveunit
 from sunpy.data.test.waveunit import MEDN_IMAGE, MQ_IMAGE, NA_IMAGE, SVSM_IMAGE
-from sunpy.extern.six.moves import range
 
 testpath = sunpy.data.test.rootdir
 
@@ -96,3 +98,21 @@ def test_extra_comment_write(tmpdir):
     outfile = tmpdir / "test.fits"
     sunpy.io.fits.write(str(outfile), data, header)
     assert outfile.exists()
+
+
+def test_simple_write_compressed(tmpdir):
+    data, header = sunpy.io.fits.read(AIA_171_IMAGE)[0]
+    outfile = tmpdir / "test.fits"
+    sunpy.io.fits.write(str(outfile), data, header, hdu_type=fits.CompImageHDU)
+    assert outfile.exists()
+    with fits.open(str(outfile)) as hdul:
+        assert len(hdul) == 2
+        assert isinstance(hdul[1], fits.CompImageHDU)
+
+def test_write_with_metadict_header_astropy(tmpdir):
+    fits_file = fits.open(AIA_171_IMAGE)
+    data, header = fits_file[0].data, fits_file[0].header
+    meta_header = MetaDict(OrderedDict(header))
+    temp_file = tmpdir / "temp.fits"
+    sunpy.io.fits.write(str(temp_file), data, meta_header)
+    assert temp_file.exists()
