@@ -56,7 +56,7 @@ class LightCurve(object):
 
     References
     ----------
-    * `Pandas Documentation <http://pandas.pydata.org/pandas-docs/dev/dsintro.html>`_
+    * `Pandas Documentation <https://pandas.pydata.org/pandas-docs/stable/>`_
 
     """
     _cond_dispatch = ConditionalDispatch()
@@ -245,19 +245,12 @@ class LightCurve(object):
         **kwargs : `dict`
             Any additional plot arguments that should be used
             when plotting.
-
-        Returns
-        -------
-        fig : `~matplotlib.Figure`
-            A plot figure.
         """
 
         figure = plt.figure()
         self.plot(**kwargs)
         figure.show()
 
-        return figure
-
     @staticmethod
     def _download(uri, kwargs,
                   err='Unable to download data at specified URL'):
@@ -275,7 +268,7 @@ class LightCurve(object):
         if "directory" in kwargs:
             download_dir = os.path.expanduser(kwargs["directory"])
         else:
-            download_dir = get_and_create_download_dir()
+            download_dir = os.path.expanduser(get_and_create_download_dir())
 
         # overwrite the existing file if the keyword is present
         if "overwrite" in kwargs:
