@@ -4,4 +4,4 @@ This is where datasource specific logic is implemented. Each mission should
 have its own file with one or more classes defined. Typically, these classes
 will be subclasses of the :mod`sunpy.LightCurve` class.
 """
-__all__ = ['rhessi', 'eve', 'goes', 'lyra', 'logical', 'noaa', 'norh']
+__all__ = ['rhessi', 'eve', 'goes', 'lyra', 'logical', 'noaa', 'norh','fermi_gbm']
