@@ -25,7 +25,7 @@ class NOAAIndicesLightCurve(LightCurve):
     2. The RI sunspot number is the official International Sunspot Number and is issued by
        the `Solar Influence Data Analysis Center (SDIC) <http://sidc.oma.be>`_ in Brussels, Belgium.
     3. The ratio between the SWO and RI indices.
-    4. Radio flux at 10.7 cm is produced by Penticon/Ottawa <http://www.ngdc.noaa.gov/stp/solar/flux.html>
+    4. Radio flux at 10.7 cm is produced by Penticon/Ottawa <https://www.ngdc.noaa.gov/stp/solar/flux.html>
        and the units are in sfu.
     5. The Ap Geomagnetic Index is produced by the United States Air Force (USAF).
 
@@ -39,11 +39,11 @@ class NOAAIndicesLightCurve(LightCurve):
 
     References
     ----------
-    * `Solar and Geomagnetic Indices Data Archive <http://legacy-www.swpc.noaa.gov/Data/index.html#indices>`_
+    * `Solar and Geomagnetic Indices Data Archive <https://www.swpc.noaa.gov/products/3-day-geomagnetic-forecast>`_
     * `Recent solar indices <ftp://ftp.swpc.noaa.gov/pub/weekly/RecentIndices.txt>`_
     * `Indices Descriptions <ftp://ftp.swpc.noaa.gov/pub/weekly/README3>`_
-    * `NOAA plots of Solar Cycle Progression <http://www.swpc.noaa.gov/products/solar-cycle-progression>`_
-    * `NOAA Product List <http://www.swpc.noaa.gov/products-and-data>`_
+    * `NOAA plots of Solar Cycle Progression <https://www.swpc.noaa.gov/products/solar-cycle-progression>`_
+    * `NOAA Product List <https://www.swpc.noaa.gov/products-and-data>`_
 
 
     """
@@ -66,12 +66,6 @@ class NOAAIndicesLightCurve(LightCurve):
 
         **plot_args : dict
             Any additional plot arguments that should be used when plotting.
-
-        Returns
-        -------
-        fig : ~matplotlib.Figure
-            A plot figure.
-
         """
 
         figure = plt.figure()
@@ -106,7 +100,6 @@ class NOAAIndicesLightCurve(LightCurve):
         axes.legend()
 
         figure.show()
-        return figure
 
     @classmethod
     def _get_default_uri(cls):
@@ -149,7 +142,7 @@ class NOAAPredictIndicesLightCurve(LightCurve):
     * The predicted RI sunspot number is the official International Sunspot
     Number and is issued by the `Solar Influence Data Analysis Center (SDIC) <http://sidc.oma.be>`_ in Brussels, Belgium.
     * The predicted radio flux at 10.7 cm is produced by
-    `Penticon/Ottawa <http://www.ngdc.noaa.gov/stp/solar/flux.html>`_ and the units are in sfu.
+    `Penticon/Ottawa <https://www.ngdc.noaa.gov/stp/solar/flux.html>`_ and the units are in sfu.
 
     Examples
     --------
@@ -160,10 +153,10 @@ class NOAAPredictIndicesLightCurve(LightCurve):
 
     References
     ----------
-    * `Solar and Geomagnetic Indices Data Archive <http://legacy-www.swpc.noaa.gov/Data/index.html#indices>`_
+    * `Solar and Geomagnetic Indices Data Archive <https://www.swpc.noaa.gov/products/3-day-geomagnetic-forecast>`_
     * `Predicted solar indices <http://services.swpc.noaa.gov/text/predicted-sunspot-radio-flux.txt>`_
-    * `NOAA plots of Solar Cycle Progression <http://www.swpc.noaa.gov/products/solar-cycle-progression>`_
-    * `NOAA Product List <http://www.swpc.noaa.gov/products-and-data>`_
+    * `NOAA plots of Solar Cycle Progression <https://www.swpc.noaa.gov/products/solar-cycle-progression>`_
+    * `NOAA Product List <https://www.swpc.noaa.gov/products-and-data>`_
 
     """
 
@@ -184,12 +177,6 @@ class NOAAPredictIndicesLightCurve(LightCurve):
         ----------
         **plot_args : dict
             Any additional plot arguments that should be used when plotting.
-
-        Returns
-        -------
-        fig : `~matplotlib.Figure`
-            A plot figure.
-
         """
 
         figure = plt.figure()
@@ -209,7 +196,6 @@ class NOAAPredictIndicesLightCurve(LightCurve):
         axes.legend()
 
         figure.show()
-        return figure
 
     @classmethod
     def _get_default_uri(cls):
