@@ -7,8 +7,8 @@ import warnings
 
 import numpy as np
 import astropy.io.fits
+from astropy.wcs import WCS
 
-import sunpy
 from sunpy.map.mapbase import GenericMap, MAP_CLASSES
 from sunpy.map.compositemap import CompositeMap
 from sunpy.map.mapcube import MapCube
@@ -31,6 +31,13 @@ from sunpy.extern import six
 
 from sunpy.extern.six.moves.urllib.request import urlopen
 
+SUPPORTED_ARRAY_TYPES = (np.ndarray,)
+try:
+    import dask.array
+    SUPPORTED_ARRAY_TYPES += (dask.array.Array,)
+except ImportError:
+    pass
+
 __authors__ = ["Russell Hewett, Stuart Mumford"]
 __email__ = "stuart@mumford.me.uk"
 
@@ -56,6 +63,7 @@ class MapFactory(BasicRegistrationFactory):
     Examples
     --------
     >>> import sunpy.map
+    >>> from astropy.io import fits
     >>> import sunpy.data.sample  # doctest: +REMOTE_DATA
     >>> mymap = sunpy.map.Map(sunpy.data.sample.AIA_171_IMAGE)  # doctest: +REMOTE_DATA
 
@@ -72,6 +80,20 @@ class MapFactory(BasicRegistrationFactory):
 
     >>> mymap = sunpy.map.Map(data, header)   # doctest: +SKIP
 
+    * data, wcs object, in tuple
+
+    >>> from astropy.wcs import WCS
+    >>> wcs = WCS(sunpy.data.sample.AIA_171_IMAGE)     # doctest: +REMOTE_DATA
+    >>> data = fits.getdata(sunpy.data.sample.AIA_171_IMAGE)    # doctest: +REMOTE_DATA
+    >>> mymap = sunpy.map.Map((data, wcs))    # doctest: +REMOTE_DATA
+
+    * data, wcs object, not in tuple
+
+    >>> from astropy.wcs import WCS
+    >>> wcs = WCS(sunpy.data.sample.AIA_171_IMAGE)     # doctest: +REMOTE_DATA
+    >>> data = fits.getdata(sunpy.data.sample.AIA_171_IMAGE)    # doctest: +REMOTE_DATA
+    >>> mymap = sunpy.map.Map(data, wcs)   # doctest: +REMOTE_DATA
+
     * File names
 
     >>> mymap = sunpy.map.Map('file1.fits')   # doctest: +SKIP
@@ -138,6 +160,8 @@ class MapFactory(BasicRegistrationFactory):
         mixture of the following entries:
         * tuples of data,header
         * data, header not in a tuple
+        * data, wcs object in a tuple
+        * data, wcs object not in a tuple
         * filename, which will be read
         * directory, from which all files will be read
         * glob, from which all files will be read
@@ -167,22 +191,16 @@ class MapFactory(BasicRegistrationFactory):
 
             arg = args[i]
 
-            # Data-header pair in a tuple
-            if ((type(arg) in [tuple, list]) and
-                len(arg) == 2 and
-                isinstance(arg[0], np.ndarray) and
-                self._validate_meta(arg[1])):
+            # Data-header or data-WCS pair
+            if isinstance(arg, SUPPORTED_ARRAY_TYPES):
+                arg_header = args[i+1]
+                if isinstance(arg_header, WCS):
+                    arg_header = args[i+1].to_header()
 
-                arg[1] = OrderedDict(arg[1])
-                data_header_pairs.append(arg)
-
-            # Data-header pair not in a tuple
-            elif (isinstance(arg, np.ndarray) and
-                  self._validate_meta(args[i+1])):
-
-                pair = (args[i], OrderedDict(args[i+1]))
-                data_header_pairs.append(pair)
-                i += 1   # an extra increment to account for the data-header pairing
+                if self._validate_meta(arg_header):
+                    pair = (args[i], OrderedDict(arg_header))
+                    data_header_pairs.append(pair)
+                    i += 1    # an extra increment to account for the data-header pairing
 
             # File name
             elif (isinstance(arg, six.string_types) and
@@ -225,6 +243,7 @@ class MapFactory(BasicRegistrationFactory):
                 raise ValueError("File not found or invalid input")
 
             i += 1
+
         # TODO:
         # In the end, if there are already maps it should be put in the same
         # order as the input, currently they are not.
