@@ -5,9 +5,9 @@ from __future__ import absolute_import, print_function, division
 __author__ = ["Jack Ireland, Jose Ivan Campos-Rozo, David Perez-Suarez"]
 __email__ = "jack.ireland@nasa.gov"
 
-import numpy as np
+import matplotlib.pyplot as plt
+
 from sunpy.map import GenericMap
-from sunpy.cm import cm
 
 __all__ = ['XRTMap', 'SOTMap']
 
@@ -33,12 +33,12 @@ class XRTMap(GenericMap):
 
     References
     ----------
-    * `Hinode Mission Page <http://solarb.msfc.nasa.gov/index.html>`_
+    * `Hinode Mission Page <https://solarb.msfc.nasa.gov/index.html>`_
     * `XRT Instrument Page <http://xrt.cfa.harvard.edu>`_
-    * `Fits header reference <http://hinode.nao.ac.jp/sbsc/SB_MW_Key13.pdf>`_
-    * `Hinode User Guide <http://hinode.nao.ac.jp/hsc_e/instruction_e.shtml>`_
+    * `Fits header reference <http://hinode.nao.ac.jp/uploads/2016/04/22/SB_MW_Key13.pdf>`_
+    * `Hinode User Guide <http://hinode.nao.ac.jp/en/for-researchers/analysis-guide/>`_
     * `XRT Analysis Guide <http://xrt.cfa.harvard.edu/science/tutorials.php>`_
-    * `Coronal Temperature Diagnostic Capability of the Hinode/X-Ray Telescope Based on Self-Consistent Calibration <http://arxiv.org/pdf/1011.2867.pdf>`_
+    * `Coronal Temperature Diagnostic Capability of the Hinode/X-Ray Telescope Based on Self-Consistent Calibration <https://arxiv.org/abs/1011.2867>`_
     """
     filter_wheel1_measurements = ["Al_med", "Al_poly", "Be_med",
                                   "Be_thin", "C_poly", "Open"]
@@ -65,9 +65,7 @@ class XRTMap(GenericMap):
         self.meta['detector'] = "XRT"
 #        self.meta['instrume'] = "XRT"
         self.meta['telescop'] = "Hinode"
-        self.meta['wavelnth'] = np.nan
-        self.meta['waveunit'] = 'keV'
-        self.plot_settings['cmap'] = cm.get_cmap(name='hinodexrt')
+        self.plot_settings['cmap'] = plt.get_cmap(name='hinodexrt')
 
     @property
     def measurement(self):
@@ -96,7 +94,7 @@ class SOTMap(GenericMap):
     ----------
     * `Hinode Mission Page <http://solarb.msfc.nasa.gov/index.html>`_
     * `Hinode SOT Instrument Page <http://sot.lmsal.com>`_
-    * `Hinode SOT Instrument Paper <http://arxiv.org/pdf/0711.1715.pdf>`_
+    * `Hinode SOT Instrument Paper <https://arxiv.org/abs/0711.1715>`_
     * `Data Analsis Guide <https://sot.lmsal.com/doc/rep/sot254/fid366/SOT00042_33_SOT_Analysis_Guide_SAG.pdf>`_
     """
     # TODO: get a link for the SOT FITS headers
@@ -133,7 +131,7 @@ class SOTMap(GenericMap):
                  'SOT/SP': 'intensity',  # For the 1st 2 dimensions
                  }
 
-        self.plot_settings['cmap'] = cm.get_cmap('hinodesot' + color[self.instrument])
+        self.plot_settings['cmap'] = plt.get_cmap('hinodesot' + color[self.instrument])
 
     @classmethod
     def is_datasource_for(cls, data, header, **kwargs):
