@@ -5,8 +5,9 @@ from __future__ import absolute_import, print_function, division
 __author__ = "Steven Christe"
 __email__ = "steven.d.christe@nasa.gov"
 
+import matplotlib.pyplot as plt
+
 from sunpy.map import GenericMap
-from sunpy.cm import cm
 
 
 __all__ = ['RHESSIMap']
@@ -29,8 +30,8 @@ class RHESSIMap(GenericMap):
 
     References
     ----------
-    * RHESSI Homepage `<http://hesperia.gsfc.nasa.gov/rhessi3/index.html>`_
-    * Mission Paper `<http://link.springer.com/article/10.1023%2FA%3A1022428818870>`_
+    * RHESSI Homepage `<https://hesperia.gsfc.nasa.gov/rhessi3/index.html>`_
+    * Mission Paper `<https://doi.org/10.1023/A:1022428818870>`_
 
     .. warning::
 
@@ -54,7 +55,7 @@ class RHESSIMap(GenericMap):
 
         self.meta['waveunit'] = 'keV'
         self.meta['wavelnth'] = [self.meta['energy_l'], self.meta['energy_h']]
-        self.plot_settings['cmap'] = cm.get_cmap('rhessi')
+        self.plot_settings['cmap'] = plt.get_cmap('rhessi')
 
     @property
     def detector(self):
