@@ -5,11 +5,12 @@ from __future__ import absolute_import, print_function, division
 __author__ = "Keith Hughitt"
 __email__ = "keith.hughitt@nasa.gov"
 
+import matplotlib.pyplot as plt
+
 from astropy.visualization.mpl_normalize import ImageNormalize
 from astropy.visualization import AsinhStretch
 
 from sunpy.map import GenericMap
-from sunpy.cm import cm
 from sunpy.map.sources.source_type import source_stretch
 
 __all__ = ['AIAMap', 'HMIMap']
@@ -30,11 +31,11 @@ class AIAMap(GenericMap):
 
     References
     ----------
-    * `SDO Mission Page <http://sdo.gsfc.nasa.gov>`_
+    * `SDO Mission Page <https://sdo.gsfc.nasa.gov/>`_
     * `Instrument Page <http://aia.lmsal.com>`_
     * `Fits Header keywords <http://jsoc.stanford.edu/doc/keywords/AIA/AIA02840_A_AIA-SDO_FITS_Keyword_Documents.pdf>`_
     * `Analysis Guide <https://www.lmsal.com/sdodocs/doc/dcur/SDOD0060.zip/zip/entry/>`_
-    * `Instrument Paper <http://link.springer.com/article/10.1007%2Fs11207-011-9776-8>`_
+    * `Instrument Paper <https://doi.org/10.1007/s11207-011-9776-8>`_
     * `wavelengths and temperature response reference <https://www.lmsal.com/sdodocs/doc/dcur/SDOD0060.zip/zip/entry/figures/aia_tel_resp.png>`_
     """
 
@@ -45,7 +46,7 @@ class AIAMap(GenericMap):
         # Fill in some missing info
         self.meta['detector'] = "AIA"
         self._nickname = self.detector
-        self.plot_settings['cmap'] = cm.get_cmap(self._get_cmap_name())
+        self.plot_settings['cmap'] = plt.get_cmap(self._get_cmap_name())
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, AsinhStretch(0.01)))
 
     @property
@@ -75,7 +76,7 @@ class HMIMap(GenericMap):
 
     References
     ----------
-    * `SDO Mission Page <http://sdo.gsfc.nasa.gov>`_
+    * `SDO Mission Page <https://sdo.gsfc.nasa.gov/>`_
     * `Instrument Page <http://hmi.stanford.edu>`_
     * `Analysis Guide <http://hmi.stanford.edu/doc/magnetic/guide.pdf>`_
     """
@@ -86,7 +87,6 @@ class HMIMap(GenericMap):
         self.meta['detector'] = "HMI"
 #        self.meta['instrme'] = "HMI"
 #        self.meta['obsrvtry'] = "SDO"
-        self.meta['waveunit'] = 'Angstrom'
         self._nickname = self.detector
 
     @property
