@@ -6,12 +6,12 @@ __author__ = "Keith Hughitt"
 __email__ = "keith.hughitt@nasa.gov"
 
 import numpy as np
+import matplotlib.pyplot as plt
 
 from astropy.visualization import PowerStretch
 from astropy.visualization.mpl_normalize import ImageNormalize
 
 from sunpy.map import GenericMap
-from sunpy.cm import cm
 from sunpy.map.sources.source_type import source_stretch
 
 __all__ = ['EUVIMap', 'CORMap', 'HIMap']
@@ -27,7 +27,7 @@ class EUVIMap(GenericMap):
 
     References
     ----------
-    * `STEREO Mission Page <http://stereo.gsfc.nasa.gov>`_
+    * `STEREO Mission Page <https://stereo.gsfc.nasa.gov/>`_
     * `STEREO SECCHI <http://secchi.nrl.navy.mil>`_
     * `Instrument Page <http://secchi.lmsal.com/EUVI/>`_
     """
@@ -35,9 +35,8 @@ class EUVIMap(GenericMap):
     def __init__(self, data, header, **kwargs):
 
         GenericMap.__init__(self, data, header, **kwargs)
-
         self._nickname = "{0}-{1}".format(self.detector, self.observatory[-1])
-        self.plot_settings['cmap'] = cm.get_cmap('sohoeit{wl:d}'.format(wl=int(self.wavelength.value)))
+        self.plot_settings['cmap'] = plt.get_cmap('sohoeit{wl:d}'.format(wl=int(self.wavelength.value)))
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, PowerStretch(0.25)))
         self.meta['waveunit'] = 'Angstrom'
 
@@ -53,7 +52,7 @@ class EUVIMap(GenericMap):
 
         References
         ----------
-        http://sohowww.nascom.nasa.gov/solarsoft/stereo/secchi/doc/FITS_keywords.pdf
+        https://sohowww.nascom.nasa.gov/solarsoft/stereo/secchi/doc/FITS_keywords.pdf
         """
         return self.meta.get('rsun', None)
 
@@ -75,11 +74,11 @@ class CORMap(GenericMap):
 
     References
     ----------
-    * `STEREO Mission Page <http://stereo.gsfc.nasa.gov>`_
+    * `STEREO Mission Page <https://stereo.gsfc.nasa.gov/>`_
     * `STEREO SECCHI <http://secchi.nrl.navy.mil>`_
-    * `COR1 Instrument Page <http://cor1.gsfc.nasa.gov>`_
+    * `COR1 Instrument Page <https://cor1.gsfc.nasa.gov>`_
     * `COR2 Instrument Page <http://secchi.nrl.navy.mil/index.php?p=cor2>`_
-    * `COR1 User Guide <http://cor1.gsfc.nasa.gov/guide/>`_
+    * `COR1 User Guide <https://cor1.gsfc.nasa.gov/guide/>`_
     """
 
     def __init__(self, data, header, **kwargs):
@@ -87,9 +86,7 @@ class CORMap(GenericMap):
         GenericMap.__init__(self, data, header, **kwargs)
 
         self._nickname = "{0}-{1}".format(self.detector, self.observatory[-1])
-        self.meta['wavelnth'] = np.nan
-        self.meta['waveunit'] = 'nm'
-        self.plot_settings['cmap'] = cm.get_cmap('stereocor{det!s}'.format(det=self.detector[-1]))
+        self.plot_settings['cmap'] = plt.get_cmap('stereocor{det!s}'.format(det=self.detector[-1]))
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, PowerStretch(0.5)))
 
         # Try to identify when the FITS meta data does not have the correct
@@ -125,17 +122,15 @@ class HIMap(GenericMap):
 
     References
     ----------
-    * `STEREO Mission Page <http://stereo.gsfc.nasa.gov>`_
-    * `STEREO SECCHI <http://secchi.nrl.navy.mil>`_
+    * `STEREO Mission Page <https://stereo.gsfc.nasa.gov/>`_
+    * `STEREO SECCHI <https://secchi.nrl.navy.mil>`_
     * `HI Instrument Page <http://www.stereo.rl.ac.uk>`_
     """
     def __init__(self, data, header, **kwargs):
 
         GenericMap.__init__(self, data, header, **kwargs)
-        self.meta['wavelnth'] = np.nan
-        self.meta['waveunit'] = 'nm'
         self._nickname = "{0}-{1}".format(self.detector, self.observatory[-1])
-        self.plot_settings['cmap'] = cm.get_cmap('stereohi{det!s}'.format(det=self.detector[-1]))
+        self.plot_settings['cmap'] = plt.get_cmap('stereohi{det!s}'.format(det=self.detector[-1]))
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, PowerStretch(0.25)))
 
         # Try to identify when the FITS meta data does not have the correct
