@@ -5,10 +5,11 @@ from __future__ import absolute_import, division, absolute_import
 __author__ = "Jack Ireland"
 __email__ = "jack.ireland@nasa.gov"
 
+import matplotlib.pyplot as plt
+
 from astropy.visualization import LogStretch
 from astropy.visualization.mpl_normalize import ImageNormalize
 from sunpy.map import GenericMap
-from sunpy.cm import cm
 from sunpy.map.sources.source_type import source_stretch
 
 __all__ = ['TRACEMap']
@@ -31,10 +32,10 @@ class TRACEMap(GenericMap):
 
     References
     ----------
-    * `Mission/Instrument Page <http://trace.lmsal.com>`_
-    * `Fits headers <http://trace.lmsal.com/Project/Instrument/cal/>`_
-    * `Analysis Guide <http://trace.lmsal.com/tag/>`_
-    * `Passband reference <http://trace.lmsal.com/Project/Instrument/inspass.htm>`_
+    * `Mission/Instrument Page <https://sdowww.lmsal.com/TRACE>`_
+    * `Fits headers <https://sdowww.lmsal.com/TRACE/Project/Instrument/cal/>`_
+    * `Analysis Guide <https://sdowww.lmsal.com/TRACE/tag/>`_
+    * `Passband reference <https://sdowww.lmsal.com/TRACE/Project/Instrument/inspass.htm>`_
 
     .. note::
 
@@ -57,7 +58,7 @@ class TRACEMap(GenericMap):
         self.meta['obsrvtry'] = "TRACE"
         self._nickname = self.detector
         # Colour maps
-        self.plot_settings['cmap'] = cm.get_cmap('trace' + str(self.meta['WAVE_LEN']))
+        self.plot_settings['cmap'] = plt.get_cmap('trace' + str(self.meta['WAVE_LEN']))
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, LogStretch()))
 
     @classmethod
