@@ -1,10 +1,4 @@
 # -*- coding: utf-8 -*-
-# Author:   Michael Malocha <mjm159@humboldt.edu>
-# Last Edit:  September 22nd, 2013
-#
-# This module was developed with funding from the GSOC 2013 summer of code
-#
-
 """
 This module is meant to parse the HELIO registry and return WSDL endpoints to
 facilitate the interfacing between further modules and HELIO.
@@ -18,8 +12,7 @@ from contextlib import closing
 from sunpy.net.helio import registry_links as RL
 from sunpy.extern.six.moves import urllib
 
-__author__ = 'Michael Malocha'
-__version__ = 'September 22nd, 2013'
+__all__ = ['webservice_parser', 'endpoint_parser', 'wsdl_retriever']
 
 # Lifespan in seconds before a link times-out
 LINK_TIMEOUT = 3
@@ -62,7 +55,7 @@ def webservice_parser(service='HEC'):
         return None
     root = EL.fromstring(xml)
     links = []
-    
+
     for interface in root.iter('interface'):
         service_type = interface.attrib
         key = list(service_type.keys())
@@ -97,7 +90,7 @@ def endpoint_parser(link):
     Examples
     --------
     >>> from sunpy.net.helio import parser
-    >>> parser.endpoint_parser('http://msslkz.mssl.ucl.ac.uk/helio-hec/HelioService')  # doctest: +REMOTE_DATA +NORMALIZE_WHITESPACE
+    >>> parser.endpoint_parser('http://msslkz.mssl.ucl.ac.uk/helio-hec/HelioService')  # doctest: +REMOTE_DATA
     ['http://helio.mssl.ucl.ac.uk:80/helio-hec/HelioService?wsdl',
     'http://helio.mssl.ucl.ac.uk:80/helio-hec/HelioService1_0?wsdl',
     'http://helio.mssl.ucl.ac.uk:80/helio-hec/HelioService1_0b?wsdl',
@@ -111,7 +104,7 @@ def endpoint_parser(link):
     endpoint_page = link_test(link)
     if endpoint_page is None:
         return None
-    soup = BeautifulSoup(endpoint_page)
+    soup = BeautifulSoup(endpoint_page, 'html.parser')
     endpoints = []
     for web_link in soup.find_all('a'):
         url = web_link.get('href')
@@ -225,17 +218,20 @@ def wsdl_retriever(service='HEC'):
         this function to take a while to return. Timeout duration can be
         controlled through the LINK_TIMEOUT value
     """
+    def fail(): raise ValueError("No online HELIO servers can be found.")
     service_links = webservice_parser(service=service)
     wsdl = None
     wsdl_links = None
     if service_links is None:
-        return None
+        fail()
     for link in service_links:
         wsdl_links = taverna_parser(link)
     if wsdl_links is None:
-        return None
+        fail()
     for end_point in wsdl_links:
         if end_point is not None and link_test(end_point) is not None:
             wsdl = end_point
             break
+    if wsdl is None:
+        fail()
     return wsdl
