@@ -3,11 +3,11 @@ Provide a set of Hypothesis Strategies for various Fido related tests.
 """
 import hypothesis.strategies as st
 from hypothesis import assume
-from hypothesis.extra.datetime import datetimes
+from hypothesis.strategies import datetimes
 
 import datetime
 from sunpy.net import attrs as a
-from sunpy.time import parse_time, TimeRange
+from sunpy.time import TimeRange
 
 
 @st.composite
@@ -48,9 +48,10 @@ def online_instruments():
 
 
 @st.composite
-def time_attr(draw, time=datetimes(timezones=[],
-                                   max_year=datetime.datetime.utcnow().year,
-                                   min_year=1900),
+def time_attr(draw, time=datetimes(
+    max_value=datetime.datetime(datetime.datetime.utcnow().year, 1, 1, 0, 0),
+    min_value=datetime.datetime(1900, 1, 1, 0, 0)
+    ),
               delta=timedelta()):
     """
     Create an a.Time where it's always positive and doesn't have a massive time
@@ -65,9 +66,9 @@ def time_attr(draw, time=datetimes(timezones=[],
 
 
 @st.composite
-def goes_time(draw, time=datetimes(timezones=[],
-                                   max_year=datetime.datetime.utcnow().year,
-                                   min_year=1981),
+def goes_time(draw, time=datetimes(
+    max_value=datetime.datetime(datetime.datetime.utcnow().year, 1, 1, 0, 0),
+    min_value=datetime.datetime(1981, 1, 1, 0, 0)),
               delta=timedelta()):
     """
     Create an a.Time where it's always positive and doesn't have a massive time
@@ -75,17 +76,21 @@ def goes_time(draw, time=datetimes(timezones=[],
     """
     t1 = draw(time)
     t2 = t1 + draw(delta)
-    # We can't download data from the future...
+    # We can't download data from the future.
     assume(t2 < datetime.datetime.utcnow())
 
     tr = TimeRange(t1, t2)
-    assume(parse_time("1983-05-01") not in tr)
+    # There is no GOES data for this date.
+    assume(datetime.datetime(1983, 5, 1, 0, 0, 0) not in tr)
+    assume((datetime.datetime(1983, 5, 1) + draw(delta)) not in tr)
 
     return a.Time(tr)
 
 
 def range_time(min_date, max_date=datetime.datetime.utcnow()):
-    time = datetimes(timezones=[], max_year=max_date.year,
-                     min_year=1960)
+    time = datetimes(
+        min_value=datetime.datetime(1960, 1, 1, 0, 0),
+        max_value=datetime.datetime(datetime.MAXYEAR, 1, 1, 0, 0),
+    )
     time = time.filter(lambda x: min_date < x < max_date)
     return time_attr(time=time)
