@@ -401,3 +401,26 @@ def test_QueryResponse_build_table_with_no_end_time():
     end_time_ = table['End Time']
     assert len(end_time_) == 1
     assert end_time_[0] == 'None'
+
+
+@pytest.mark.remote_data
+def test_vso_hmi(client, tmpdir):
+    """
+    This is a regression test for https://github.com/sunpy/sunpy/issues/2284
+    """
+    res = client.search(va.Time('2017-09-02 23:52:00', '2017-09-02 23:54:00'),
+                        va.Instrument('HMI') | va.Instrument('AIA'))
+
+    dr = client.make_getdatarequest(res)
+
+    # Extract the DRIs from the request
+    dris = dr.request.datacontainer.datarequestitem
+
+    # 3 HMI series and one AIA
+    assert len(dris) == 4
+
+    # For each DataRequestItem assert that there is only one series in it.
+    for dri in dris:
+        fileids = dri.fileiditem.fileid[0]
+        series = list(map(lambda x: x.split(':')[0], fileids))
+        assert all([s == series[0] for s in series])
