@@ -14,10 +14,12 @@ This module provides a wrapper around the VSO API.
 import re
 import os
 import sys
+import copy
 import logging
 import requests
 import warnings
 import socket
+import itertools
 
 from datetime import datetime, timedelta
 from functools import partial
@@ -167,6 +169,13 @@ class QueryResponse(list):
         )
 
     def build_table(self):
+        """
+        Create a human readable table.
+
+        Returns
+        -------
+        table : `astropy.table.QTable`
+        """
         keywords = ['Start Time', 'End Time', 'Source', 'Instrument', 'Type', 'Wavelength']
         record_items = {}
         for key in keywords:
@@ -217,6 +226,11 @@ class QueryResponse(list):
     def response_block_properties(self):
         """
         Returns a set of class attributes on all the response blocks.
+
+        Returns
+        -------
+        s : list
+            List of strings, containing attribute names in the response blocks.
         """
         s = {a if not a.startswith('_') else None for a in dir(self[0])}
         for resp in self[1:]:
@@ -310,7 +324,7 @@ class VSOClient(object):
         >>> client = vso.VSOClient()  # doctest: +REMOTE_DATA
         >>> client.search(
         ...    vso.attrs.Time(datetime(2010, 1, 1), datetime(2010, 1, 1, 1)),
-        ...    vso.attrs.Instrument('eit') | vso.attrs.Instrument('aia'))   # doctest: +NORMALIZE_WHITESPACE +REMOTE_DATA
+        ...    vso.attrs.Instrument('eit') | vso.attrs.Instrument('aia'))   # doctest:  +REMOTE_DATA
         <QTable length=5>
            Start Time [1]       End Time [1]    Source ...   Type   Wavelength [2]
                                                        ...             Angstrom
@@ -324,8 +338,9 @@ class VSOClient(object):
 
         Returns
         -------
-        out : :py:class:`QueryResult` (enhanced list) of matched items. Return
-        value of same type as the one of :py:meth:`VSOClient.query`.
+        out : :py:class:`QueryResult` (enhanced list)
+            Matched items. Return value is of same type as the one of
+            :py:meth:`VSOClient.query`.
         """
         query = and_(*query)
 
@@ -495,8 +510,9 @@ class VSOClient(object):
 
         Returns
         -------
-        out : :py:class:`QueryResult` (enhanced list) of matched items. Return
-              value of same type as the one of :py:class:`VSOClient.query`.
+        out : :py:class:`QueryResult` (enhanced list)
+            Matched items. Return value is of same type as the one of
+            :py:class:`VSOClient.query`.
         """
         sdk = lambda key: lambda value: {key: value}
         ALIASES = {
@@ -564,7 +580,7 @@ class VSOClient(object):
         )
 
     def fetch(self, query_response, path=None, methods=('URL-FILE_Rice', 'URL-FILE'),
-            downloader=None, site=None):
+              downloader=None, site=None):
         """
         Download data specified in the query_response.
 
@@ -610,8 +626,9 @@ class VSOClient(object):
 
         Returns
         -------
-        out : :py:class:`Results` object that supplies a list of filenames with meta attributes
-              containing the respective QueryResponse.
+        out : :py:class:`Results`
+            Object that supplies a list of filenames with meta attributes
+            containing the respective QueryResponse.
 
         Examples
         --------
@@ -661,7 +678,6 @@ class VSOClient(object):
         """
         return self.fetch(query_response, path=path, methods=methods, downloader=downloader, site=site)
 
-
     @staticmethod
     def link(query_response, maps):
         """ Return list of paths with records associated with them in
@@ -697,14 +713,37 @@ class VSOClient(object):
         if info is None:
             info = {}
 
+        # For the JSOC provider we need to make a DataRequestItem for each
+        # series, not just one for the whole provider.
+
+        # Remove JSOC provider items from the map
+        jsoc = maps.pop('JSOC', [])
+
+        # Make DRIs for everything that's not JSOC one per provider
+        dris = [self.make('DataRequestItem', provider=k, fileiditem__fileid=[v])
+                for k, v in iteritems(maps)]
+
+        def series_func(x):
+            """ Extract the series from the fileid. """
+            return x.split(':')[0]
+
+        # Sort the JSOC fileids by series
+        # This is a precursor to groupby as recommended by the groupby docs
+        series_sorted = sorted(jsoc, key=series_func)
+
+        # Iterate over the series and make a DRI for each.
+        # groupby creates an iterator based on a key function, in this case
+        # based on the series (the part before the first ':')
+        for series, fileids in itertools.groupby(series_sorted, key=series_func):
+            dris.append(self.make('DataRequestItem',
+                                  provider='JSOC',
+                                  fileiditem__fileid=[list(fileids)]))
+
         return self.make(
             'VSOGetDataRequest',
             request__method__methodtype=methods,
             request__info=info,
-            request__datacontainer__datarequestitem=[
-                self.make('DataRequestItem', provider=k, fileiditem__fileid=[v])
-                for k, v in iteritems(maps)
-            ]
+            request__datacontainer__datarequestitem=dris
         )
 
     # pylint: disable=R0913,R0912
@@ -928,6 +967,7 @@ class InteractiveVSOClient(VSOClient):
 
 g_client = None
 
+
 @deprecated("0.8.0", alternative="Please use the VSO Clients directly")
 def search(*args, **kwargs):
     # pylint: disable=W0603
@@ -939,6 +979,7 @@ def search(*args, **kwargs):
 
 search.__doc__ = InteractiveVSOClient.search.__doc__
 
+
 @deprecated("0.8.0", alternative="Please use the VSO Clients directly")
 def get(query_response, path=None, methods=('URL-FILE',), downloader=None):
     # pylint: disable=W0603
