@@ -6,6 +6,7 @@ from __future__ import absolute_import, division, print_function
 import warnings
 import tempfile
 import platform
+import os
 
 import pytest
 import numpy as np
@@ -74,6 +75,8 @@ def figure_test(test_function):
     @pytest.mark.figure
     @wraps(test_function)
     def wrapper(*args, **kwargs):
+        if not os.path.exists(hash.HASH_LIBRARY_FILE):
+            pytest.xfail('Could not find a figure hash library at {}'.format(hash.HASH_LIBRARY_FILE))
         plt.figure()
         name = "{0}.{1}".format(test_function.__module__, test_function.__name__)
         pngfile = tempfile.NamedTemporaryFile(delete=False)
