@@ -12,10 +12,6 @@ def julian_day(t='now'):
     """
     return Time(parse_time(t)).jd
 
-# The number of days between Jan 1 1900 and the Julian reference date of
-# 12:00 noon Jan 1, 4713 BC
-JULIAN_DAY_ON_NOON01JAN1900 = 2415021.0
-
 
 def julian_centuries(t='now'):
     """Returns the number of Julian centuries since J1900.0 (noon on 1900 January 0)."""
