@@ -37,11 +37,20 @@ class TimeRange(object):
     Examples
     --------
     >>> from sunpy.time import TimeRange
+    >>> import astropy.units as u
     >>> time_range = TimeRange('2010/03/04 00:10', '2010/03/04 00:20')
     >>> time_range = TimeRange(('2010/03/04 00:10', '2010/03/04 00:20'))
-    >>> import astropy.units as u
     >>> time_range = TimeRange('2010/03/04 00:10', 400 * u.s)
-    >>> time_range = TimeRange('2010/03/04 00:10', 400 * u.day)
+    >>> TimeRange('2010/03/04 00:10', 400 * u.day) # doctest:+ELLIPSIS
+       <sunpy.time.timerange.TimeRange object at ...>
+        Start: 2010-03-04 00:10:00
+        End:   2011-04-08 00:10:00
+        Center:2010-09-20 00:10:00
+        Duration:400.0 days or
+               9600.0 hours or
+               576000.0 minutes or
+               34560000.0 seconds
+    <BLANKLINE>
     """
     def __init__(self, a, b=None):
         """Creates a new TimeRange instance"""
@@ -298,7 +307,7 @@ class TimeRange(object):
         >>> import astropy.units as u
         >>> from sunpy.time import TimeRange
         >>> time_range = TimeRange('2010/03/04 00:10', '2010/03/04 01:20')
-        >>> time_range.window(60*60*u.s, window=12*u.s)   # doctest: +NORMALIZE_WHITESPACE +SKIP
+        >>> time_range.window(60*60*u.s, window=12*u.s)   # doctest:  +SKIP
         [   <sunpy.time.timerange.TimeRange object at 0x7f0214bfc208>
             Start: 2010-03-04 00:10:00
             End:   2010-03-04 00:10:12
