@@ -45,15 +45,15 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
 
     Examples
     --------
-    >>> import sunpy.data.sample
+    >>> import sunpy.data.sample  # doctest: +REMOTE_DATA
     >>> import sunpy.timeseries
-    >>> rhessi = sunpy.timeseries.TimeSeries(sunpy.data.sample.RHESSI_TIMESERIES)
+    >>> rhessi = sunpy.timeseries.TimeSeries(sunpy.data.sample.RHESSI_TIMESERIES)  # doctest: +REMOTE_DATA
     >>> rhessi.peek()   # doctest: +SKIP
 
     References
     ----------
-    * RHESSI Homepage `<http://hesperia.gsfc.nasa.gov/rhessi3/index.html>`_
-    * Mission Paper `<http://link.springer.com/article/10.1023%2FA%3A1022428818870>`_
+    * RHESSI Homepage `<https://hesperia.gsfc.nasa.gov/rhessi3/index.html>`_
+    * Mission Paper `<https://doi.org/10.1023/A:1022428818870>`_
     """
 
     # Class attribute used to specify the source class of the TimeSeries.
@@ -77,11 +77,6 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
         **kwargs : `dict`
             Any additional plot arguments that should be used
             when plotting.
-
-        Returns
-        -------
-        fig : `~matplotlib.Figure`
-            A plot figure.
         """
         # Check we have a timeseries valid for plotting
         self._validate_data_for_ploting()
@@ -89,8 +84,6 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
         figure = plt.figure()
         axes = plt.gca()
 
-        #dates = matplotlib.dates.date2num(self.data.index)
-
         lc_linecolors = rhessi.hsi_linecolors()
 
         for lc_color, (item, frame) in zip(lc_linecolors, self.data.iteritems()):
@@ -99,7 +92,7 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
         axes.set_yscale("log")
         axes.set_xlabel(datetime.datetime.isoformat(self.data.index[0])[0:10])
 
-        axes.set_title('RHESSI Observing Summary Count Rates')
+        axes.set_title(title)
         axes.set_ylabel('Count Rate s$^{-1}$ detector$^{-1}$')
 
         axes.yaxis.grid(True, 'major')
@@ -137,7 +130,7 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
                              ('300 - 800 keV', u.ct / u.s / u.Unit('detector')),
                              ('800 - 7000 keV', u.ct / u.s / u.Unit('detector')),
                              ('7000 - 20000 keV', u.ct / u.s / u.Unit('detector'))])
-        # Todo: check units used. http://hesperia.gsfc.nasa.gov/ssw/hessi/doc/guides/hessi_data_access.htm
+        # Todo: check units used. https://hesperia.gsfc.nasa.gov/ssw/hessi/doc/guides/hessi_data_access.htm
         return data, header, units
 
     @classmethod
