@@ -23,6 +23,7 @@ def test_xml_to_dict1():
 
     assert xml_dict == expected_dict
 
+
 def test_xml_to_dict2():
     """
     should return dict of xml string
@@ -40,6 +41,7 @@ def test_xml_to_dict2():
 
     assert xml_dict == expected_dict
 
+
 def test_xml_to_dict3():
     """
     should return dict of xml string
@@ -52,6 +54,7 @@ def test_xml_to_dict3():
 
     assert xml_dict == expected_dict
 
+
 def test_xml_to_dict4():
     """
     should return dict of xml string
@@ -64,6 +67,7 @@ def test_xml_to_dict4():
 
     assert xml_dict == expected_dict
 
+
 def test_xml_to_dict5():
     """
     should return dict of xml string
@@ -83,6 +87,7 @@ def test_xml_to_dict5():
 
     assert xml_dict == expected_dict
 
+
 def test_xml_to_dict6():
     """
     should return dict of xml string
@@ -102,24 +107,28 @@ def test_xml_to_dict6():
 
     assert xml_dict == expected_dict
 
+
 def test_xml_to_dict7():
     """
     should raise TypeError when passed None
     """
     assert pytest.raises(TypeError, xml.xml_to_dict, None)
 
+
 def test_xml_to_dict8():
     """
     should raise TypeError when passed non string
     """
     assert pytest.raises(TypeError, xml.xml_to_dict, 9)
 
+
 def test_xml_to_dict9():
     """
     should raise ExpatError when passed empty string
     """
     assert pytest.raises(ExpatError, xml.xml_to_dict, "")
 
+
 def test_xml_to_dict10():
     """
     should raise ExpatError when passed space
@@ -136,12 +145,14 @@ def test_get_node_text1():
     doc.appendChild(outer)
     pytest.raises(xml.NotTextNodeError, xml.get_node_text, doc)
 
+
 def test_get_node_text2():
     """
     should return empty string for a node with no child nodes.
     """
     assert xml.get_node_text(Document()) == ""
 
+
 def test_get_node_text3():
     """
     should return node text
@@ -151,18 +162,21 @@ def test_get_node_text3():
 
     assert xml.get_node_text(text_node) == "one"
 
+
 def test_get_node_text4():
     """
      should raise AttributeError when sent None
     """
     assert pytest.raises(AttributeError, xml.get_node_text, None)
 
+
 def test_get_node_text5():
     """
      should raise AttributeError when sent wrong type
     """
     assert pytest.raises(AttributeError, xml.get_node_text, "wrong type")
 
+
 def test_node_to_dict1():
     """
     should return dict of node
@@ -188,6 +202,7 @@ def test_node_to_dict1():
 
     assert xml_dict == expected_dict
 
+
 def test_node_to_dict2():
     """
     should return dict of node double nested
@@ -218,6 +233,7 @@ def test_node_to_dict2():
 
     assert xml_dict == expected_dict
 
+
 def test_node_to_dict3():
     """
     should return empty dict when sent empty doc
@@ -227,14 +243,71 @@ def test_node_to_dict3():
 
     assert xml_dict == expected_dict
 
+
 def test_node_to_dict4():
     """
     should raise AttributeError when sent wrong type
     """
     assert pytest.raises(AttributeError, xml.node_to_dict, 9)
 
+
 def test_node_to_dict5():
     """
     should raise AttributeError when sent None
     """
     assert pytest.raises(AttributeError, xml.node_to_dict, None)
+
+
+def test_with_multiple_children_in_list():
+    """
+    Setting the 'multiple' attribute of parent node should put child nodes
+    in a list.
+    """
+    def getChild(lst_of_children, key, value):
+        for child in lst_of_children:
+            if child[key] == value:
+                return child
+
+        raise ValueError("No children with key {0} set to {1} found.".format(key, value))
+
+    source = '''<?xml version="1.0" encoding="UTF-8"?>
+                <Config>
+                    <Name>With multiple children</Name>
+                    <Children multiple="true">
+                      <Child>
+                        <Name>First Child</Name>
+                        <Value>Value 1</Value>
+                      </Child>
+                      <Child>
+                        <Name>Second Child</Name>
+                        <Value>Value 2</Value>
+                      </Child>
+                    </Children>
+                </Config>'''
+
+    expected = {'Config': {'Children': [{'Name': 'First Child', 'Value': 'Value 1'},
+                                        {'Name': 'Second Child', 'Value': 'Value 2'}],
+                           'Name': 'With multiple children'}}
+
+    actual = xml.xml_to_dict(source)
+
+    assert len(expected['Config']) == len(actual['Config'])
+    assert expected['Config']['Name'] == actual['Config']['Name']
+
+    assert len(actual['Config']['Children']) == 2
+
+    # As the child dictionaries are in lists we cannot be certain what order
+    # they are in. Test individualy.
+
+    expected_children = expected['Config']['Children']
+    actual_children = actual['Config']['Children']
+
+    expected_first_child = getChild(expected_children, key='Name', value='First Child')
+    actual_first_child = getChild(actual_children, key='Name', value='First Child')
+
+    assert expected_first_child == actual_first_child
+
+    expected_second_child = getChild(expected_children, key='Name', value='Second Child')
+    actual_second_child = getChild(actual_children, key='Name', value='Second Child')
+
+    assert expected_second_child == actual_second_child
